# Results of the warehouse reshuffling problem with swap moves and time limit

The results of the warehouse reshuffling problem with swap moves and time limit (WRPST) are provided as comma-separated value (CSV) files.
First, the file 'instances.csv' contains general information about the instances, having five columns where
- 'Instance' corresponds to the instance name,
- 'n' is the number of storage locations,
- 'Beta' is the parameter $\beta$ describing how large the reshuffling time limit is as a function of 'n',
- 'T' is the absolute reshuffling time limit, and
- 'LB_best' corresponds to the best known lower bound.

Second, the file 'results.csv' contains the results obtained by the solution algorithms, having six columns where
- 'Instance' corresponds to the instance name,
- 'Algorithm' is the name of the used solution algorithm corresponding to results in the row,
- 'Rep' provides the current number of the repetition in which the algorithm was applied on this instance (only the randomized algorithm 'SA' has multiple repetitions),
- 'RT' is the solution's total reshuffling time,
- 'AC' are the obtained assignment costs (i.e., the key objective function to be minimized), and
- 'Computing_time_seconds' corresponds to the computing time in seconds.

Overall, we implemented the following solution algorithms:
- Greedy exchange heuristic (GEH)
- Index extractor (ID)
- Greedy extractor (GD)
- Move time extractor (MT)
- Pallet weight extractor (PW)
- Depot distance extractor (DD)
- Weight depot distance extractor (WD)
- Simulated annealing (SA)
- Sorting approach + Greedy construction heuristic with cutting off the reshuffling at the time limit (Sorting+GCH)
- Matching approach + Greedy construction heuristic with cutting off the reshuffling at the time limit (Matching+GCH)

Third, the file 'lower-bounds.csv' contains the lower bound values obtained by the three different lower bound procedures 'LB_infinity', 'LB_LP' and 'LB_ILP' described in the paper.
The file contains five columns where
- 'Instance' corresponds to the instance name,
- 'Procedure' is the used lower bound procedure,
- 'LB' is the obtained lower bound value for the assignment costs objective function,
- 'LP_gap' is the percentage LP gap obtained by CPLEX, and
- 'Computing_time_seconds' corresponds to the computing time in seconds.

Fourth, the file 'final-assignments.csv' contains the results obtained by our procedures to determine optimal final storage assignments when relaxing the reshuffling time limit.
The sorting approach assigns the pallets sorted in descending order by their weights to the storage locations sorted in ascending order by their distances.
The matching approach tries to find such storage assignments which can additionally be reached within a small amount of reshuffling time.
The file contains seven columns where
- 'Instance' corresponds to the instance name,
- 'Type' is the type applied to find a final assignment (Sorting/Matching),
- 'Number_cycles' corresponds to the number of cycles corresponding to the determined final assignment,
- 'Number_swap_moves' corresponds to the number of swap moves required to obtain the determined final storage assignment,
- 'RT' is the resulting total reshuffling time required by the GCH,
- 'AC' are the obtained assignment costs, and
- 'Computing_time_seconds' corresponds to the computing time in seconds.
